@@ -1,19 +1,19 @@
 /*
-**  Copyright (c) 2005, 2006 Sendmail, Inc. and its suppliers.
+**  Copyright (c) 2005-2007 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  $Id: dkim-filter.h,v 1.38 2006/09/18 17:23:17 msk Exp $
+**  $Id: dkim-filter.h,v 1.45 2007/03/07 15:50:09 msk Exp $
 */
 
 #ifndef _DKIM_FILTER_H_
 #define _DKIM_FILTER_H_
 
 #ifndef lint
-static char dkim_filter_h_id[] = "@(#)$Id: dkim-filter.h,v 1.38 2006/09/18 17:23:17 msk Exp $";
+static char dkim_filter_h_id[] = "@(#)$Id: dkim-filter.h,v 1.45 2007/03/07 15:50:09 msk Exp $";
 #endif /* !lint */
 
 #define	DKIMF_PRODUCT	"Sendmail DKIM Filter"
-#define	DKIMF_VERSION	"0.5.2"
+#define	DKIMF_VERSION	"0.6.1"
 
 /* libdkim */
 #include <dkim.h>
@@ -31,7 +31,7 @@ static char dkim_filter_h_id[] = "@(#)$Id: dkim-filter.h,v 1.38 2006/09/18 17:23
 #if _FFR_SET_DNS_CALLBACK
 #define	CBINTERVAL	3
 #endif /* _FFR_SET_DNS_CALLBACK */
-#define CMDLINEOPTS	"a:Ab:c:C:d:DfFhi:I:k:Klm:M:p:P:rRs:S:T:u:U:v:Vx:"
+#define CMDLINEOPTS	"a:Ab:c:C:d:DfFhi:I:k:Klm:M:op:P:qrRs:S:T:u:U:v:Vx:"
 #define	DEFTIMEOUT	5
 #define	HOSTUNKNOWN	"unknown-host"
 #define	JOBIDUNKNOWN	"(unknown-jobid)"
