@@ -1,12 +1,12 @@
 /*
-**  Copyright (c) 2005, 2006 Sendmail, Inc. and its suppliers.
+**  Copyright (c) 2005-2007 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  $Id: util.c,v 1.11 2006/06/07 22:19:01 msk Exp $
+**  $Id: util.c,v 1.14 2007/03/01 22:32:08 msk Exp $
 */
 
 #ifndef lint
-static char util_c_id[] = "@(#)$Id: util.c,v 1.11 2006/06/07 22:19:01 msk Exp $";
+static char util_c_id[] = "@(#)$Id: util.c,v 1.14 2007/03/01 22:32:08 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -42,6 +42,10 @@ static char util_c_id[] = "@(#)$Id: util.c,v 1.11 2006/06/07 22:19:01 msk Exp $"
 
 static char *ffrlist[] =
 {
+#if _FFR_ALLMAN_SSP_02
+	"_FFR_ALLMAN_SSP_02",
+#endif /* _FFR_ALLMAN_SSP_02 */
+
 #if _FFR_FLUSH_HEADERS
 	"_FFR_FLUSH_HEADERS",
 #endif /* _FFR_FLUSH_HEADERS */
@@ -78,10 +82,6 @@ static char *ffrlist[] =
 	"_FFR_SET_REPLY",
 #endif /* _FFR_SET_REPLY */
 
-#if _FFR_VERIFY_DOMAINKEYS
-	"_FFR_VERIFY_DOMAINKEYS",
-#endif /* _FFR_VERIFY_DOMAINKEYS */
-
 	NULL
 };
 
