@@ -1,10 +1,10 @@
 /*
-**  Copyright (c) 2005 Sendmail, Inc. and its suppliers.
+**  Copyright (c) 2005-2007 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 */
 
 #ifndef lint
-static char dkim_keys_c_id[] = "@(#)$Id: dkim-keys.c,v 1.7 2006/04/26 22:44:57 msk Exp $";
+static char dkim_keys_c_id[] = "@(#)$Id: dkim-keys.c,v 1.8 2007/03/01 18:34:31 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -265,6 +265,17 @@ dkim_get_key_dns(DKIM *dkim, u_char *buf, size_t buflen)
 **
 **  Return value:
 **  	A DKIM_STAT_* constant.
+**
+**  Notes:
+**  	The file opened is defined by the library option DKIM_OPTS_QUERYINFO
+**  	and must be set prior to use of this function.  Failing to do
+**  	so will cause this function to return DKIM_STAT_KEYFAIL every time.
+**  	The file should contain lines of the form:
+** 
+**  		selector@domain <space> key-data
+**
+**  	Case matching on the left is case-sensitive, but libdkim already
+**  	wraps the domain name to lowercase.
 */
 
 DKIM_STAT
@@ -280,9 +291,19 @@ dkim_get_key_file(DKIM *dkim, u_char *buf, size_t buflen)
 	assert(dkim->dkim_domain != NULL);
 	assert(dkim->dkim_querymethod == DKIM_QUERY_FILE);
 
-	f = fopen(DKIM_TEST_KEYSFILE, "r");
-	if (f == NULL)
+	path = dkim->dkim_libhandle->dkimf_queryinfo;
+	if (path[0] == '\0')
+	{
+		dkim_error(dkim, "query file not defined");
 		return DKIM_STAT_KEYFAIL;
+	}
+
+	f = fopen(path, "r");
+	if (f == NULL)
+	{
+		dkim_error(dkim, "%s: fopen(): %s", path, strerror(errno));
+		return DKIM_STAT_KEYFAIL;
+	}
 
 	snprintf(name, sizeof name, "%s@%s", dkim->dkim_selector,
 	         dkim->dkim_domain);
@@ -302,13 +323,20 @@ dkim_get_key_file(DKIM *dkim, u_char *buf, size_t buflen)
 			else if (isascii(*p) && isspace(*p))
 			{
 				*p = '\0';
-				if (p2 == NULL)
-					p2 = p + 1;
+				p2 = p + 1;
+			}
+			else if (p2 != NULL)
+			{
+				break;
 			}
 		}
 
 		if (strcmp(name, buf) == 0)
+		{
 			sm_strlcpy(buf, p2, buflen);
+			fclose(f);
+			return DKIM_STAT_OK;
+		}
 	}
 
 	fclose(f);
