@@ -1,10 +1,10 @@
 /*
-**  Copyright (c) 2005, 2006 Sendmail, Inc. and its suppliers.
+**  Copyright (c) 2005-2007 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 */
 
 #ifndef lint
-static char dkim_tables_c_id[] = "@(#)$Id: dkim-tables.c,v 1.15 2006/09/15 17:23:33 msk Exp $";
+static char dkim_tables_c_id[] = "@(#)$Id: dkim-tables.c,v 1.17 2007/03/02 00:53:59 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -97,6 +97,7 @@ static struct nametable prv_sigparams[] =	/* signature parameters */
 	{ "d",		DKIM_PARAM_DOMAIN },
 	{ "h",		DKIM_PARAM_HDRLIST },
 	{ "i",		DKIM_PARAM_IDENTITY },
+	{ "l",		DKIM_PARAM_BODYLENGTH },
 	{ "q",		DKIM_PARAM_QUERYMETHOD },
 	{ "s",		DKIM_PARAM_SELECTOR },
 	{ "t",		DKIM_PARAM_TIMESTAMP },
@@ -165,6 +166,15 @@ static struct nametable prv_results[] =		/* result codes */
 };
 struct nametable *results = prv_results;
 
+static struct nametable prv_settypes[] =	/* set types */
+{
+	{ "key",	DKIM_SETTYPE_KEY },
+	{ "policy",	DKIM_SETTYPE_POLICY },
+	{ "signature",	DKIM_SETTYPE_SIGNATURE },
+	{ NULL,		-1 },
+};
+struct nametable *settypes = prv_settypes;
+
 /* ===================================================================== */
 
 /*
