@@ -1,5 +1,5 @@
 /*
-**  Copyright (c) 2005, 2006 Sendmail, Inc. and its suppliers.
+**  Copyright (c) 2005-2007 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 */
 
@@ -7,7 +7,7 @@
 #define _DKIM_TYPES_H_
 
 #ifndef lint
-static char dkim_types_h_id[] = "@(#)$Id: dkim-types.h,v 1.36 2006/09/15 05:08:28 msk Exp $";
+static char dkim_types_h_id[] = "@(#)$Id: dkim-types.h,v 1.38 2007/03/01 18:34:49 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -122,6 +122,7 @@ struct dkim
 	size_t			dkim_b64siglen;
 	size_t			dkim_keylen;
 	size_t			dkim_siglen;
+	size_t			dkim_errlen;
 	time_t			dkim_timestamp;
 	dkim_query_t		dkim_querymethod;
 	dkim_canon_t		dkim_hdrcanonalg;
@@ -143,6 +144,7 @@ struct dkim
 	u_char *		dkim_reportaddr;
 	u_char *		dkim_sender;
 	u_char *		dkim_signer;
+	u_char *		dkim_error;
 	u_char **		dkim_shset;
 	char *			dkim_tmpdir;
 	void *			dkim_hash;
@@ -170,9 +172,11 @@ struct dkim_lib
 	u_int			dkiml_flags;
 	u_int			dkiml_timeout;
 	u_int			dkiml_version;
+	dkim_query_t		dkiml_querymethod;
 	void *			(*dkiml_malloc) (void *closure, size_t nbytes);
 	void			(*dkiml_free) (void *closure, void *p);
 	u_char			dkiml_tmpdir[MAXPATHLEN + 1];
+	u_char			dkiml_queryinfo[MAXPATHLEN + 1];
 #if USE_ARLIB
 	AR_LIB			dkiml_arlib;
 #endif /* USE_ARLIB */
