@@ -1,5 +1,5 @@
 /*
-**  Copyright (c) 2005, 2006 Sendmail, Inc. and its suppliers.
+**  Copyright (c) 2005-2007 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 */
 
@@ -7,7 +7,7 @@
 #define _DKIM_H_
 
 #ifndef lint
-static char dkim_h_id[] = "@(#)$Id: dkim.h,v 1.48 2006/09/15 23:50:20 msk Exp $";
+static char dkim_h_id[] = "@(#)$Id: dkim.h,v 1.55 2007/03/02 00:53:59 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -53,11 +53,15 @@ static char dkim_h_id[] = "@(#)$Id: dkim.h,v 1.48 2006/09/15 23:50:20 msk Exp $"
 #define MAXTAGNAME		8	/* biggest tag name */
 
 /* defaults */
+#define	DEFERRLEN		64	/* default error string length */
 #define	DEFTMPDIR		"/var/tmp"
 					/* default temporary directory */
 
 /* version */
-#define	DKIM_VERSION		"DKIM1"	/* current version token */
+#define	DKIM_VERSION_KEY	"DKIM1"	/* current version token for keys */
+#define	DKIM_VERSION_SIG	"1"	/* current version token for sigs */
+#define	DKIM_VERSION_SIG_DRAFT1	"0.2"	/* draft version token for sigs */
+#define	DKIM_VERSION_SIG_DRAFT2	"0.5"	/* draft version token for sigs */
 
 /* headers */
 #define	DKIM_SIGNHEADER		"DKIM-Signature"
@@ -83,7 +87,8 @@ static char dkim_h_id[] = "@(#)$Id: dkim.h,v 1.48 2006/09/15 23:50:20 msk Exp $"
 #define DKIM_VERSION_IETF_BASE_00	2
 #define DKIM_VERSION_IETF_BASE_01	3
 #define DKIM_VERSION_IETF_BASE_02	4
-#define DKIM_VERSION_DEFAULT		DKIM_VERSION_IETF_BASE_02
+#define DKIM_VERSION_IETF_BASE_10	5
+#define DKIM_VERSION_DEFAULT		DKIM_VERSION_IETF_BASE_10
 
 /*
 **  DKIM_STAT -- status code type
@@ -139,9 +144,9 @@ typedef int dkim_query_t;
 
 #define DKIM_QUERY_UNKNOWN	-1	/* unknown method */
 #define DKIM_QUERY_DNS		0	/* DNS query method (per the draft) */
-#if DKIM_TEST
-# define DKIM_QUERY_FILE	1	/* text file method (for testing) */
-#endif /* DKIM_TEST */
+#if DKIM_QUERY_FILE
+# define DKIM_QUERY_FILE	1	/* text file method */
+#endif /* DKIM_QUERY_FILE */
 
 #define DKIM_QUERY_DEFAULT	DKIM_QUERY_DNS
 
@@ -164,6 +169,7 @@ typedef int dkim_param_t;
 #define DKIM_PARAM_EXPIRATION	10	/* x */
 #define DKIM_PARAM_COPIEDHDRS	11	/* z */
 #define DKIM_PARAM_BODYHASH	12	/* bh */
+#define DKIM_PARAM_BODYLENGTH	13	/* l */
 
 /*
 **  DKIM_KEY -- known key parameters
@@ -275,6 +281,8 @@ typedef int dkim_opts_t;
 #define	DKIM_OPTS_SENDERHDRS	3
 #define	DKIM_OPTS_SIGNHDRS	4
 #define	DKIM_OPTS_VERSION	5
+#define	DKIM_OPTS_QUERYMETHOD	6
+#define	DKIM_OPTS_QUERYINFO	7
 
 #define	DKIM_LIBFLAGS_NONE	0x00
 #define	DKIM_LIBFLAGS_TMPFILES	0x01
@@ -382,7 +390,7 @@ extern DKIM_LIB *dkim_init __P((void *(*mallocf)(void *closure, size_t nbytes),
 */
 
 extern DKIM *dkim_sign __P((DKIM_LIB *libhandle, const char *id,
-                            void *memclosure, const dkim_sigkey_t *secretkey,
+                            void *memclosure, const dkim_sigkey_t secretkey,
                             const char *selector, const char *domain,
                             dkim_canon_t hdr_canon_alg,
                             dkim_canon_t body_canon_alg,
@@ -644,6 +652,19 @@ extern DKIM_STAT dkim_set_dns_callback __P((DKIM *dkim,
 
 extern DKIM_STAT dkim_free __P((DKIM *dkim));
 
+/*
+**  DKIM_GETERROR -- return any stored error string from within the DKIM
+**                   context handle
+**
+**  Parameters:
+**  	dkim -- DKIM handle from which to retrieve an error string
+**
+**  Return value:
+**  	A pointer to the stored string, or NULL if none was stored.
+*/
+
+extern const char *dkim_geterror __P((DKIM *dkim));
+
 /*
 **  rfc2822_mailbox_split -- extract the userid and host from a structured
 **                           header
