@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char util_c_id[] = "@(#)$Id: util.c,v 1.9 2005/12/01 01:06:10 msk Exp $";
+static char util_c_id[] = "@(#)$Id: util.c,v 1.10 2006/09/13 19:14:55 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -116,7 +116,8 @@ dkim_islwsp(u_int c)
 **  	s1, s2 -- the strings
 **
 **  Return value:
-**  	Like strcmp().
+**  	Like strcmp().  However, if "s2" contains only a domain name,
+**  	don't bother comparing the local-parts.
 */
 
 int
@@ -131,6 +132,7 @@ dkim_addrcmp(u_char *s1, u_char *s2)
 	at1 = (u_char *) strchr(s1, '@');
 	at2 = (u_char *) strchr(s2, '@');
 
+	/* if one or both contain no "@"s, just be strcmp() */
 	if (at1 == NULL || at2 == NULL)
 		return strcmp(s1, s2);
 
@@ -138,17 +140,27 @@ dkim_addrcmp(u_char *s1, u_char *s2)
 	*at1 = '\0';
 	*at2 = '\0';
 
-	ret = strcmp(s1, s2);
-	if (ret != 0)
+	/* if "s2" contains only a domain name, skip the local-part check */
+	if (at2 != s2)
 	{
-		*at1 = '@';
-		*at2 = '@';
+		/* compare the local-parts, case-sensitive */
+		ret = strcmp(s1, s2);
+		if (ret != 0)
+		{
+			*at1 = '@';
+			*at2 = '@';
 
-		return ret;
+			return ret;
+		}
 	}
 
-	/* now check the domains */
-	return strcasecmp(at1 + 1, at2 + 1);
+	/* now compare the domains, case-insensitive */
+	ret = strcasecmp(at1 + 1, at2 + 1);
+
+	*at1 = '@';
+	*at2 = '@';
+
+	return ret;
 }
 
 /*
